@@ -397,12 +397,11 @@ typedef enum UGSliceProperty {
 /**
  * Create a new grail context
  *
- * @param [in] frame_handle The frame context object
  * @param [out] handle The new grail context object
  * @return UGStatusSuccess or UGStatusErrorResources
  */
 GRAIL_PUBLIC
-UGStatus grail_new(UFHandle frame_handle, UGHandle *handle);
+UGStatus grail_new(UGHandle *handle);
 
 /**
  * Delete a grail context
@@ -410,7 +409,7 @@ UGStatus grail_new(UFHandle frame_handle, UGHandle *handle);
  * @param [in] handle The grail context object
  */
 GRAIL_PUBLIC
-void grail_delete_v3(UGHandle handle);
+void grail_delete(UGHandle handle);
 
 /**
  * Get the event file descriptor for the frame context
